This file is auto-generated and should reflect the current state.

This is a list of supported PyTorch modules and functions.
See also [what is unsupported (on a higher level)](Unsupported.md).

- [x] `torch.nn.parameter` (module)
- [ ] `torch.nn.grad` (module)
- [x] `torch.nn.functional` (module)
- [x] `torch.nn.init` (module)
- [x] `torch.nn.common_types` (module)
- [x] `torch.nn.utils` (module)
- [x] `torch.nn.modules` (module)
- [x] `torch.nn.Module` (torch.nn.Module)
- [x] `torch.nn.Identity` (torch.nn.Module)
- [x] `torch.nn.Linear` (torch.nn.Module)
- [x] `torch.nn.Conv1d` (torch.nn.Module)
- [x] `torch.nn.Conv2d` (torch.nn.Module)
- [ ] `torch.nn.Conv3d` (torch.nn.Module)
- [x] `torch.nn.ConvTranspose1d` (torch.nn.Module)
- [x] `torch.nn.ConvTranspose2d` (torch.nn.Module)
- [ ] `torch.nn.ConvTranspose3d` (torch.nn.Module)
- [ ] `torch.nn.Threshold` (torch.nn.Module)
- [x] `torch.nn.ReLU` (torch.nn.Module)
- [ ] `torch.nn.Hardtanh` (torch.nn.Module)
- [ ] `torch.nn.ReLU6` (torch.nn.Module)
- [x] `torch.nn.Sigmoid` (torch.nn.Module)
- [x] `torch.nn.Tanh` (torch.nn.Module)
- [x] `torch.nn.Softmax` (torch.nn.Module)
- [ ] `torch.nn.Softmax2d` (torch.nn.Module)
- [x] `torch.nn.LogSoftmax` (torch.nn.Module)
- [ ] `torch.nn.ELU` (torch.nn.Module)
- [ ] `torch.nn.SELU` (torch.nn.Module)
- [ ] `torch.nn.CELU` (torch.nn.Module)
- [ ] `torch.nn.GLU` (torch.nn.Module)
- [x] `torch.nn.GELU` (torch.nn.Module)
- [ ] `torch.nn.Hardshrink` (torch.nn.Module)
- [x] `torch.nn.LeakyReLU` (torch.nn.Module)
- [x] `torch.nn.LogSigmoid` (torch.nn.Module)
- [ ] `torch.nn.Softplus` (torch.nn.Module)
- [ ] `torch.nn.Softshrink` (torch.nn.Module)
- [ ] `torch.nn.MultiheadAttention` (torch.nn.Module)
- [ ] `torch.nn.PReLU` (torch.nn.Module)
- [ ] `torch.nn.Softsign` (torch.nn.Module)
- [ ] `torch.nn.Softmin` (torch.nn.Module)
- [ ] `torch.nn.Tanhshrink` (torch.nn.Module)
- [ ] `torch.nn.RReLU` (torch.nn.Module)
- [ ] `torch.nn.L1Loss` (torch.nn.Module)
- [ ] `torch.nn.NLLLoss` (torch.nn.Module)
- [ ] `torch.nn.KLDivLoss` (torch.nn.Module)
- [ ] `torch.nn.MSELoss` (torch.nn.Module)
- [ ] `torch.nn.BCELoss` (torch.nn.Module)
- [ ] `torch.nn.BCEWithLogitsLoss` (torch.nn.Module)
- [ ] `torch.nn.NLLLoss2d` (torch.nn.Module)
- [ ] `torch.nn.PoissonNLLLoss` (torch.nn.Module)
- [ ] `torch.nn.CosineEmbeddingLoss` (torch.nn.Module)
- [ ] `torch.nn.CTCLoss` (torch.nn.Module)
- [ ] `torch.nn.HingeEmbeddingLoss` (torch.nn.Module)
- [ ] `torch.nn.MarginRankingLoss` (torch.nn.Module)
- [ ] `torch.nn.MultiLabelMarginLoss` (torch.nn.Module)
- [ ] `torch.nn.MultiLabelSoftMarginLoss` (torch.nn.Module)
- [ ] `torch.nn.MultiMarginLoss` (torch.nn.Module)
- [ ] `torch.nn.SmoothL1Loss` (torch.nn.Module)
- [ ] `torch.nn.SoftMarginLoss` (torch.nn.Module)
- [ ] `torch.nn.CrossEntropyLoss` (torch.nn.Module)
- [ ] `torch.nn.Container` (torch.nn.Module)
- [x] `torch.nn.Sequential` (torch.nn.Module)
- [x] `torch.nn.ModuleList` (torch.nn.Module)
- [ ] `torch.nn.ModuleDict` (torch.nn.Module)
- [ ] `torch.nn.ParameterList` (torch.nn.Module)
- [ ] `torch.nn.ParameterDict` (torch.nn.Module)
- [ ] `torch.nn.AvgPool1d` (torch.nn.Module)
- [ ] `torch.nn.AvgPool2d` (torch.nn.Module)
- [ ] `torch.nn.AvgPool3d` (torch.nn.Module)
- [x] `torch.nn.MaxPool1d` (torch.nn.Module)
- [x] `torch.nn.MaxPool2d` (torch.nn.Module)
- [ ] `torch.nn.MaxPool3d` (torch.nn.Module)
- [ ] `torch.nn.MaxUnpool1d` (torch.nn.Module)
- [ ] `torch.nn.MaxUnpool2d` (torch.nn.Module)
- [ ] `torch.nn.MaxUnpool3d` (torch.nn.Module)
- [ ] `torch.nn.FractionalMaxPool2d` (torch.nn.Module)
- [ ] `torch.nn.FractionalMaxPool3d` (torch.nn.Module)
- [ ] `torch.nn.LPPool1d` (torch.nn.Module)
- [ ] `torch.nn.LPPool2d` (torch.nn.Module)
- [ ] `torch.nn.LocalResponseNorm` (torch.nn.Module)
- [x] `torch.nn.BatchNorm1d` (torch.nn.Module)
- [ ] `torch.nn.BatchNorm2d` (torch.nn.Module)
- [ ] `torch.nn.BatchNorm3d` (torch.nn.Module)
- [ ] `torch.nn.InstanceNorm1d` (torch.nn.Module)
- [ ] `torch.nn.InstanceNorm2d` (torch.nn.Module)
- [ ] `torch.nn.InstanceNorm3d` (torch.nn.Module)
- [x] `torch.nn.LayerNorm` (torch.nn.Module)
- [x] `torch.nn.GroupNorm` (torch.nn.Module)
- [ ] `torch.nn.SyncBatchNorm` (torch.nn.Module)
- [x] `torch.nn.Dropout` (torch.nn.Module)
- [ ] `torch.nn.Dropout2d` (torch.nn.Module)
- [ ] `torch.nn.Dropout3d` (torch.nn.Module)
- [ ] `torch.nn.AlphaDropout` (torch.nn.Module)
- [ ] `torch.nn.FeatureAlphaDropout` (torch.nn.Module)
- [x] `torch.nn.ReflectionPad1d` (torch.nn.Module)
- [ ] `torch.nn.ReflectionPad2d` (torch.nn.Module)
- [ ] `torch.nn.ReplicationPad2d` (torch.nn.Module)
- [x] `torch.nn.ReplicationPad1d` (torch.nn.Module)
- [ ] `torch.nn.ReplicationPad3d` (torch.nn.Module)
- [ ] `torch.nn.CrossMapLRN2d` (torch.nn.Module)
- [x] `torch.nn.Embedding` (torch.nn.Module)
- [ ] `torch.nn.EmbeddingBag` (torch.nn.Module)
- [x] `torch.nn.RNNBase` (torch.nn.Module)
- [ ] `torch.nn.RNN` (torch.nn.Module)
- [x] `torch.nn.LSTM` (torch.nn.Module)
- [ ] `torch.nn.GRU` (torch.nn.Module)
- [ ] `torch.nn.RNNCellBase` (torch.nn.Module)
- [ ] `torch.nn.RNNCell` (torch.nn.Module)
- [ ] `torch.nn.LSTMCell` (torch.nn.Module)
- [ ] `torch.nn.GRUCell` (torch.nn.Module)
- [ ] `torch.nn.PixelShuffle` (torch.nn.Module)
- [ ] `torch.nn.Upsample` (torch.nn.Module)
- [ ] `torch.nn.UpsamplingNearest2d` (torch.nn.Module)
- [ ] `torch.nn.UpsamplingBilinear2d` (torch.nn.Module)
- [ ] `torch.nn.PairwiseDistance` (torch.nn.Module)
- [ ] `torch.nn.AdaptiveMaxPool1d` (torch.nn.Module)
- [ ] `torch.nn.AdaptiveMaxPool2d` (torch.nn.Module)
- [ ] `torch.nn.AdaptiveMaxPool3d` (torch.nn.Module)
- [ ] `torch.nn.AdaptiveAvgPool1d` (torch.nn.Module)
- [ ] `torch.nn.AdaptiveAvgPool2d` (torch.nn.Module)
- [ ] `torch.nn.AdaptiveAvgPool3d` (torch.nn.Module)
- [ ] `torch.nn.TripletMarginLoss` (torch.nn.Module)
- [ ] `torch.nn.ZeroPad2d` (torch.nn.Module)
- [x] `torch.nn.ConstantPad1d` (torch.nn.Module)
- [ ] `torch.nn.ConstantPad2d` (torch.nn.Module)
- [ ] `torch.nn.ConstantPad3d` (torch.nn.Module)
- [ ] `torch.nn.Bilinear` (torch.nn.Module)
- [ ] `torch.nn.CosineSimilarity` (torch.nn.Module)
- [ ] `torch.nn.Unfold` (torch.nn.Module)
- [ ] `torch.nn.Fold` (torch.nn.Module)
- [ ] `torch.nn.AdaptiveLogSoftmaxWithLoss` (torch.nn.Module)
- [ ] `torch.nn.TransformerEncoder` (torch.nn.Module)
- [ ] `torch.nn.TransformerDecoder` (torch.nn.Module)
- [ ] `torch.nn.TransformerEncoderLayer` (torch.nn.Module)
- [ ] `torch.nn.TransformerDecoderLayer` (torch.nn.Module)
- [ ] `torch.nn.Transformer` (torch.nn.Module)
- [x] `torch.nn.Flatten` (torch.nn.Module)
- [x] `torch.nn.Unflatten` (torch.nn.Module)
- [ ] `torch.nn.Hardsigmoid` (torch.nn.Module)
- [ ] `torch.nn.Hardswish` (torch.nn.Module)
- [ ] `torch.nn.SiLU` (torch.nn.Module)
- [ ] `torch.nn.TripletMarginWithDistanceLoss` (torch.nn.Module)
- [x] `torch.nn.Parameter` (class)
- [ ] `torch.nn.parallel` (module)
- [ ] `torch.nn.DataParallel` (torch.nn.Module)
- [ ] `torch.nn.intrinsic` (module)
- [ ] `torch.nn.qat` (module)
- [ ] `torch.nn.quantized` (module)
- [ ] `torch.nn.functional.utils` (module)
- [ ] `torch.nn.functional.grad` (module)
- [ ] `torch.nn.functional.boolean_dispatch` (function)
- [ ] `torch.nn.functional.has_torch_function` (function)
- [ ] `torch.nn.functional.handle_torch_function` (function)
- [x] `torch.nn.functional.Tensor` (class)
- [x] `torch.nn.functional.conv1d` (function)
- [x] `torch.nn.functional.conv2d` (function)
- [ ] `torch.nn.functional.conv3d` (function)
- [x] `torch.nn.functional.conv_transpose1d` (function)
- [ ] `torch.nn.functional.conv_transpose2d` (function)
- [ ] `torch.nn.functional.conv_transpose3d` (function)
- [ ] `torch.nn.functional.conv_tbc` (function)
- [ ] `torch.nn.functional.avg_pool1d` (function)
- [ ] `torch.nn.functional.avg_pool2d` (function)
- [ ] `torch.nn.functional.avg_pool3d` (function)
- [ ] `torch.nn.functional.fractional_max_pool2d_with_indices` (function)
- [ ] `torch.nn.functional.fractional_max_pool2d` (function)
- [ ] `torch.nn.functional.fractional_max_pool3d_with_indices` (function)
- [ ] `torch.nn.functional.fractional_max_pool3d` (function)
- [ ] `torch.nn.functional.max_pool1d_with_indices` (function)
- [ ] `torch.nn.functional.max_pool1d` (function)
- [ ] `torch.nn.functional.max_pool2d_with_indices` (function)
- [x] `torch.nn.functional.max_pool2d` (function)
- [ ] `torch.nn.functional.max_pool3d_with_indices` (function)
- [ ] `torch.nn.functional.max_pool3d` (function)
- [ ] `torch.nn.functional.max_unpool1d` (function)
- [ ] `torch.nn.functional.max_unpool2d` (function)
- [ ] `torch.nn.functional.max_unpool3d` (function)
- [ ] `torch.nn.functional.lp_pool2d` (function)
- [ ] `torch.nn.functional.lp_pool1d` (function)
- [ ] `torch.nn.functional.adaptive_max_pool1d_with_indices` (function)
- [ ] `torch.nn.functional.adaptive_max_pool1d` (function)
- [ ] `torch.nn.functional.adaptive_max_pool2d_with_indices` (function)
- [ ] `torch.nn.functional.adaptive_max_pool2d` (function)
- [ ] `torch.nn.functional.adaptive_max_pool3d_with_indices` (function)
- [ ] `torch.nn.functional.adaptive_max_pool3d` (function)
- [ ] `torch.nn.functional.adaptive_avg_pool1d` (function)
- [ ] `torch.nn.functional.adaptive_avg_pool2d` (function)
- [ ] `torch.nn.functional.adaptive_avg_pool3d` (function)
- [x] `torch.nn.functional.dropout` (function)
- [ ] `torch.nn.functional.alpha_dropout` (function)
- [ ] `torch.nn.functional.dropout2d` (function)
- [ ] `torch.nn.functional.dropout3d` (function)
- [ ] `torch.nn.functional.feature_alpha_dropout` (function)
- [ ] `torch.nn.functional.threshold` (function)
- [ ] `torch.nn.functional.threshold_` (function)
- [x] `torch.nn.functional.relu` (function)
- [ ] `torch.nn.functional.relu_` (function)
- [ ] `torch.nn.functional.glu` (function)
- [ ] `torch.nn.functional.hardtanh` (function)
- [ ] `torch.nn.functional.hardtanh_` (function)
- [ ] `torch.nn.functional.relu6` (function)
- [ ] `torch.nn.functional.elu` (function)
- [ ] `torch.nn.functional.elu_` (function)
- [ ] `torch.nn.functional.selu` (function)
- [ ] `torch.nn.functional.selu_` (function)
- [ ] `torch.nn.functional.celu` (function)
- [ ] `torch.nn.functional.celu_` (function)
- [x] `torch.nn.functional.leaky_relu` (function)
- [ ] `torch.nn.functional.leaky_relu_` (function)
- [ ] `torch.nn.functional.prelu` (function)
- [ ] `torch.nn.functional.rrelu` (function)
- [ ] `torch.nn.functional.rrelu_` (function)
- [x] `torch.nn.functional.logsigmoid` (function)
- [ ] `torch.nn.functional.gelu` (function)
- [ ] `torch.nn.functional.hardshrink` (function)
- [ ] `torch.nn.functional.tanhshrink` (function)
- [ ] `torch.nn.functional.softsign` (function)
- [ ] `torch.nn.functional.softplus` (function)
- [ ] `torch.nn.functional.softmin` (function)
- [x] `torch.nn.functional.softmax` (function)
- [ ] `torch.nn.functional.gumbel_softmax` (function)
- [x] `torch.nn.functional.log_softmax` (function)
- [ ] `torch.nn.functional.softshrink` (function)
- [x] `torch.nn.functional.tanh` (function)
- [x] `torch.nn.functional.sigmoid` (function)
- [ ] `torch.nn.functional.hardsigmoid` (function)
- [ ] `torch.nn.functional.linear` (function)
- [ ] `torch.nn.functional.bilinear` (function)
- [ ] `torch.nn.functional.silu` (function)
- [ ] `torch.nn.functional.hardswish` (function)
- [ ] `torch.nn.functional.embedding` (function)
- [ ] `torch.nn.functional.embedding_bag` (function)
- [ ] `torch.nn.functional.batch_norm` (function)
- [ ] `torch.nn.functional.instance_norm` (function)
- [ ] `torch.nn.functional.layer_norm` (function)
- [x] `torch.nn.functional.group_norm` (function)
- [ ] `torch.nn.functional.local_response_norm` (function)
- [ ] `torch.nn.functional.ctc_loss` (function)
- [ ] `torch.nn.functional.nll_loss` (function)
- [ ] `torch.nn.functional.poisson_nll_loss` (function)
- [ ] `torch.nn.functional.kl_div` (function)
- [ ] `torch.nn.functional.cross_entropy` (function)
- [ ] `torch.nn.functional.binary_cross_entropy` (function)
- [ ] `torch.nn.functional.binary_cross_entropy_with_logits` (function)
- [ ] `torch.nn.functional.smooth_l1_loss` (function)
- [ ] `torch.nn.functional.l1_loss` (function)
- [ ] `torch.nn.functional.mse_loss` (function)
- [ ] `torch.nn.functional.margin_ranking_loss` (function)
- [ ] `torch.nn.functional.hinge_embedding_loss` (function)
- [ ] `torch.nn.functional.multilabel_margin_loss` (function)
- [ ] `torch.nn.functional.soft_margin_loss` (function)
- [ ] `torch.nn.functional.multilabel_soft_margin_loss` (function)
- [ ] `torch.nn.functional.cosine_embedding_loss` (function)
- [ ] `torch.nn.functional.multi_margin_loss` (function)
- [ ] `torch.nn.functional.pixel_shuffle` (function)
- [ ] `torch.nn.functional.channel_shuffle` (function)
- [ ] `torch.nn.functional.upsample` (function)
- [ ] `torch.nn.functional.interpolate` (function)
- [ ] `torch.nn.functional.upsample_nearest` (function)
- [ ] `torch.nn.functional.upsample_bilinear` (function)
- [ ] `torch.nn.functional.GRID_SAMPLE_INTERPOLATION_MODES` (dict)
- [ ] `torch.nn.functional.GRID_SAMPLE_PADDING_MODES` (dict)
- [ ] `torch.nn.functional.grid_sample` (function)
- [ ] `torch.nn.functional.affine_grid` (function)
- [x] `torch.nn.functional.pad` (function)
- [ ] `torch.nn.functional.pairwise_distance` (function)
- [ ] `torch.nn.functional.pdist` (function)
- [ ] `torch.nn.functional.cosine_similarity` (function)
- [ ] `torch.nn.functional.one_hot` (function)
- [ ] `torch.nn.functional.triplet_margin_loss` (function)
- [ ] `torch.nn.functional.triplet_margin_with_distance_loss` (function)
- [x] `torch.nn.functional.normalize` (function)
- [ ] `torch.nn.functional.assert_int_or_pair` (function)
- [ ] `torch.nn.functional.unfold` (function)
- [ ] `torch.nn.functional.fold` (function)
- [ ] `torch.nn.functional.multi_head_attention_forward` (function)
- [ ] `torch.platform` (module)
- [ ] `torch.textwrap` (module)
- [ ] `torch.ctypes` (module)
- [ ] `torch.get_file_path` (function)
- [ ] `torch.prepare_multiprocessing_environment` (function)
- [ ] `torch.USE_RTLD_GLOBAL_WITH_LIBTORCH` (bool)
- [ ] `torch.USE_GLOBAL_DEPS` (bool)
- [ ] `torch.version` (module)
- [ ] `torch.Set` (_GenericAlias)
- [ ] `torch.Type` (class)
- [ ] `torch.get_num_threads` (function)
- [ ] `torch.set_num_threads` (function)
- [ ] `torch.get_num_interop_threads` (function)
- [ ] `torch.set_num_interop_threads` (function)
- [ ] `torch.set_flush_denormal` (function)
- [ ] `torch.get_default_dtype` (function)
- [ ] `torch.is_grad_enabled` (function)
- [ ] `torch.set_autocast_enabled` (function)
- [ ] `torch.is_autocast_enabled` (function)
- [ ] `torch.clear_autocast_cache` (function)
- [ ] `torch.autocast_increment_nesting` (function)
- [ ] `torch.autocast_decrement_nesting` (function)
- [ ] `torch.set_anomaly_enabled` (function)
- [ ] `torch.is_anomaly_enabled` (function)
- [ ] `torch.Generator` (class)
- [ ] `torch.FatalError` (class)
- [x] `torch.Size` (class)
- [x] `torch.dtype` (class)
- [ ] `torch.finfo` (class)
- [ ] `torch.iinfo` (class)
- [ ] `torch.layout` (class)
- [ ] `torch.memory_format` (class)
- [ ] `torch.qscheme` (class)
- [x] `torch.device` (class)
- [ ] `torch.JITException` (class)
- [ ] `torch.IODescriptor` (class)
- [ ] `torch.CompleteArgumentSpec` (class)
- [ ] `torch.ArgumentSpec` (class)
- [ ] `torch.Code` (class)
- [ ] `torch.ExecutionPlan` (class)
- [ ] `torch.Gradient` (class)
- [ ] `torch.GraphExecutorState` (class)
- [ ] `torch.PyTorchFileWriter` (class)
- [ ] `torch.MobileOptimizerType` (class)
- [ ] `torch.CONV_BN_FUSION` (MobileOptimizerType)
- [ ] `torch.INSERT_FOLD_PREPACK_OPS` (MobileOptimizerType)
- [ ] `torch.REMOVE_DROPOUT` (MobileOptimizerType)
- [ ] `torch.FUSE_ADD_RELU` (MobileOptimizerType)
- [ ] `torch.HOIST_CONV_PACKED_PARAMS` (MobileOptimizerType)
- [ ] `torch.PyTorchFileReader` (class)
- [ ] `torch.parse_ir` (function)
- [ ] `torch.parse_schema` (function)
- [ ] `torch.unify_type_list` (function)
- [ ] `torch.FunctionSchema` (class)
- [ ] `torch.Argument` (class)
- [ ] `torch.Future` (class)
- [ ] `torch.fork` (function)
- [ ] `torch.wait` (function)
- [ ] `torch.ScriptClass` (class)
- [ ] `torch.Graph` (class)
- [ ] `torch.Value` (class)
- [ ] `torch.Block` (class)
- [ ] `torch.Node` (class)
- [ ] `torch.AnyType` (class)
- [ ] `torch.NumberType` (class)
- [ ] `torch.IntType` (class)
- [ ] `torch.FloatType` (class)
- [ ] `torch.TensorType` (class)
- [ ] `torch.BoolType` (class)
- [ ] `torch.StringType` (class)
- [ ] `torch.DeviceObjType` (class)
- [ ] `torch.PyObjectType` (class)
- [ ] `torch.NoneType` (class)
- [ ] `torch.TupleType` (class)
- [ ] `torch.ListType` (class)
- [ ] `torch.DictType` (class)
- [ ] `torch.OptionalType` (class)
- [ ] `torch.RRefType` (class)
- [ ] `torch.FutureType` (class)
- [ ] `torch.ClassType` (class)
- [ ] `torch.EnumType` (class)
- [ ] `torch.InterfaceType` (class)
- [ ] `torch.Use` (class)
- [ ] `torch.TracingState` (class)
- [ ] `torch.Capsule` (class)
- [ ] `torch.ScriptObject` (class)
- [ ] `torch.DeepCopyMemoTable` (class)
- [ ] `torch.ScriptModule` (class)
- [ ] `torch.LiteScriptModule` (class)
- [ ] `torch.ParameterDict` (class)
- [ ] `torch.BufferDict` (class)
- [ ] `torch.ModuleDict` (class)
- [ ] `torch.ErrorReport` (class)
- [ ] `torch.CompilationUnit` (class)
- [ ] `torch.ScriptFunction` (class)
- [ ] `torch.ScriptMethod` (class)
- [ ] `torch.CallStack` (class)
- [ ] `torch.parse_type_comment` (function)
- [ ] `torch.merge_type_from_type_comment` (function)
- [ ] `torch.import_ir_module` (function)
- [ ] `torch.import_ir_module_from_buffer` (function)
- [ ] `torch.FileCheck` (class)
- [ ] `torch.ConcreteModuleTypeBuilder` (class)
- [ ] `torch.ConcreteModuleType` (class)
- [ ] `torch.LoggerBase` (class)
- [ ] `torch.AggregationType` (class)
- [ ] `torch.SUM` (AggregationType)
- [ ] `torch.AVG` (AggregationType)
- [ ] `torch.LockingLogger` (class)
- [ ] `torch.NoopLogger` (class)
- [ ] `torch.StaticRuntime` (class)
- [ ] `torch.BenchmarkConfig` (class)
- [ ] `torch.BenchmarkExecutionStats` (class)
- [ ] `torch.ThroughputBenchmark` (class)
- [ ] `torch.cpp` (module)
- [ ] `torch.HalfStorageBase` (class)
- [ ] `torch.QInt8StorageBase` (class)
- [ ] `torch.QInt32StorageBase` (class)
- [ ] `torch.CudaDoubleStorageBase` (class)
- [ ] `torch.CudaFloatStorageBase` (class)
- [ ] `torch.CudaHalfStorageBase` (class)
- [ ] `torch.CudaLongStorageBase` (class)
- [ ] `torch.CudaIntStorageBase` (class)
- [ ] `torch.CudaShortStorageBase` (class)
- [ ] `torch.CudaCharStorageBase` (class)
- [ ] `torch.CudaByteStorageBase` (class)
- [ ] `torch.CudaBoolStorageBase` (class)
- [ ] `torch.CudaBFloat16StorageBase` (class)
- [ ] `torch.CudaComplexDoubleStorageBase` (class)
- [ ] `torch.CudaComplexFloatStorageBase` (class)
- [ ] `torch.has_cudnn` (bool)
- [ ] `torch.init_num_threads` (function)
- [ ] `torch.has_openmp` (bool)
- [ ] `torch.has_mkl` (bool)
- [ ] `torch.has_lapack` (bool)
- [ ] `torch.has_cuda` (bool)
- [ ] `torch.has_mkldnn` (bool)
- [ ] `torch.default_generator` (Generator)
- [ ] `torch.DisableTorchFunction` (class)
- [ ] `torch.typename` (function)
- [ ] `torch.is_tensor` (function)
- [ ] `torch.is_storage` (function)
- [ ] `torch.set_default_tensor_type` (function)
- [ ] `torch.set_default_dtype` (function)
- [ ] `torch.set_deterministic` (function)
- [ ] `torch.is_deterministic` (function)
- [x] `torch.utils` (module)
- [x] `torch.tensor` (function)
- [x] `torch.Tensor` (class)
- [ ] `torch.storage` (module)
- [ ] `torch.DoubleStorage` (class)
- [ ] `torch.FloatStorage` (class)
- [ ] `torch.HalfStorage` (class)
- [ ] `torch.LongStorage` (class)
- [ ] `torch.IntStorage` (class)
- [ ] `torch.ShortStorage` (class)
- [ ] `torch.CharStorage` (class)
- [ ] `torch.ByteStorage` (class)
- [ ] `torch.BoolStorage` (class)
- [ ] `torch.BFloat16Storage` (class)
- [ ] `torch.ComplexDoubleStorage` (class)
- [ ] `torch.ComplexFloatStorage` (class)
- [ ] `torch.QUInt8Storage` (class)
- [ ] `torch.QInt8Storage` (class)
- [ ] `torch.QInt32Storage` (class)
- [ ] `torch.random` (module)
- [ ] `torch.set_rng_state` (function)
- [ ] `torch.get_rng_state` (function)
- [ ] `torch.manual_seed` (function)
- [ ] `torch.initial_seed` (function)
- [ ] `torch.seed` (function)
- [ ] `torch.types` (module)
- [x] `torch.serialization` (module)
- [ ] `torch.save` (function)
- [x] `torch.load` (function)
- [ ] `torch.set_printoptions` (function)
- [ ] `torch.strided` (layout)
- [ ] `torch.sparse_coo` (layout)
- [ ] `torch.preserve_format` (memory_format)
- [ ] `torch.contiguous_format` (memory_format)
- [ ] `torch.channels_last` (memory_format)
- [ ] `torch.channels_last_3d` (memory_format)
- [ ] `torch.per_tensor_affine` (qscheme)
- [ ] `torch.per_channel_affine` (qscheme)
- [ ] `torch.per_tensor_symmetric` (qscheme)
- [ ] `torch.per_channel_symmetric` (qscheme)
- [ ] `torch.per_channel_affine_float_qparams` (qscheme)
- [ ] `torch.uint8` (dtype)
- [ ] `torch.int8` (dtype)
- [ ] `torch.int16` (dtype)
- [ ] `torch.short` (dtype)
- [ ] `torch.int32` (dtype)
- [ ] `torch.int` (dtype)
- [ ] `torch.int64` (dtype)
- [ ] `torch.long` (dtype)
- [ ] `torch.float16` (dtype)
- [ ] `torch.half` (dtype)
- [ ] `torch.float32` (dtype)
- [ ] `torch.float` (dtype)
- [ ] `torch.float64` (dtype)
- [ ] `torch.double` (dtype)
- [ ] `torch.complex32` (dtype)
- [ ] `torch.complex64` (dtype)
- [ ] `torch.cfloat` (dtype)
- [ ] `torch.complex128` (dtype)
- [ ] `torch.cdouble` (dtype)
- [ ] `torch.bool` (dtype)
- [ ] `torch.qint8` (dtype)
- [ ] `torch.quint8` (dtype)
- [ ] `torch.qint32` (dtype)
- [ ] `torch.bfloat16` (dtype)
- [ ] `torch.Storage` (class)
- [ ] `torch.ByteTensor` (class)
- [ ] `torch.CharTensor` (class)
- [ ] `torch.DoubleTensor` (class)
- [x] `torch.FloatTensor` (class)
- [ ] `torch.IntTensor` (class)
- [x] `torch.LongTensor` (class)
- [ ] `torch.ShortTensor` (class)
- [ ] `torch.HalfTensor` (class)
- [ ] `torch.BoolTensor` (class)
- [ ] `torch.BFloat16Tensor` (class)
- [x] `torch.cuda` (module)
- [ ] `torch.sparse` (module)
- [ ] `torch.name` (str)
- [x] `torch.abs` (function)
- [ ] `torch.abs_` (function)
- [ ] `torch.absolute` (function)
- [ ] `torch.acos` (function)
- [ ] `torch.acos_` (function)
- [ ] `torch.acosh` (function)
- [ ] `torch.acosh_` (function)
- [ ] `torch.adaptive_avg_pool1d` (function)
- [ ] `torch.adaptive_max_pool1d` (function)
- [x] `torch.add` (function)
- [ ] `torch.addbmm` (function)
- [ ] `torch.addcdiv` (function)
- [ ] `torch.addcmul` (function)
- [ ] `torch.addmm` (function)
- [ ] `torch.addmv` (function)
- [ ] `torch.addmv_` (function)
- [ ] `torch.addr` (function)
- [ ] `torch.affine_grid_generator` (function)
- [ ] `torch.align_tensors` (function)
- [ ] `torch.all` (function)
- [ ] `torch.allclose` (function)
- [ ] `torch.alpha_dropout` (function)
- [ ] `torch.alpha_dropout_` (function)
- [ ] `torch.amax` (function)
- [ ] `torch.amin` (function)
- [ ] `torch.angle` (function)
- [ ] `torch.any` (function)
- [ ] `torch.arange` (function)
- [ ] `torch.arccos` (function)
- [ ] `torch.arccos_` (function)
- [ ] `torch.arccosh` (function)
- [ ] `torch.arccosh_` (function)
- [ ] `torch.arcsin` (function)
- [ ] `torch.arcsin_` (function)
- [ ] `torch.arcsinh` (function)
- [ ] `torch.arcsinh_` (function)
- [ ] `torch.arctan` (function)
- [ ] `torch.arctan_` (function)
- [ ] `torch.arctanh` (function)
- [ ] `torch.arctanh_` (function)
- [ ] `torch.argmax` (function)
- [ ] `torch.argmin` (function)
- [ ] `torch.argsort` (function)
- [ ] `torch.as_strided` (function)
- [ ] `torch.as_strided_` (function)
- [x] `torch.as_tensor` (function)
- [ ] `torch.asin` (function)
- [ ] `torch.asin_` (function)
- [ ] `torch.asinh` (function)
- [ ] `torch.asinh_` (function)
- [ ] `torch.atan` (function)
- [ ] `torch.atan2` (function)
- [ ] `torch.atan_` (function)
- [ ] `torch.atanh` (function)
- [ ] `torch.atanh_` (function)
- [ ] `torch.atleast_1d` (function)
- [ ] `torch.atleast_2d` (function)
- [ ] `torch.atleast_3d` (function)
- [ ] `torch.avg_pool1d` (function)
- [ ] `torch.baddbmm` (function)
- [ ] `torch.bartlett_window` (function)
- [ ] `torch.batch_norm` (function)
- [ ] `torch.batch_norm_backward_elemt` (function)
- [ ] `torch.batch_norm_backward_reduce` (function)
- [ ] `torch.batch_norm_elemt` (function)
- [ ] `torch.batch_norm_gather_stats` (function)
- [ ] `torch.batch_norm_gather_stats_with_counts` (function)
- [ ] `torch.batch_norm_stats` (function)
- [ ] `torch.batch_norm_update_stats` (function)
- [ ] `torch.bernoulli` (function)
- [ ] `torch.bilinear` (function)
- [ ] `torch.binary_cross_entropy_with_logits` (function)
- [ ] `torch.bincount` (function)
- [ ] `torch.binomial` (function)
- [ ] `torch.bitwise_and` (function)
- [ ] `torch.bitwise_not` (function)
- [ ] `torch.bitwise_or` (function)
- [ ] `torch.bitwise_xor` (function)
- [ ] `torch.blackman_window` (function)
- [ ] `torch.block_diag` (function)
- [ ] `torch.bmm` (function)
- [ ] `torch.broadcast_tensors` (function)
- [ ] `torch.bucketize` (function)
- [ ] `torch.can_cast` (function)
- [ ] `torch.cartesian_prod` (function)
- [ ] `torch.cat` (function)
- [ ] `torch.cdist` (function)
- [ ] `torch.ceil` (function)
- [ ] `torch.ceil_` (function)
- [ ] `torch.celu` (function)
- [ ] `torch.celu_` (function)
- [ ] `torch.chain_matmul` (function)
- [ ] `torch.channel_shuffle` (function)
- [ ] `torch.cholesky` (function)
- [ ] `torch.cholesky_inverse` (function)
- [ ] `torch.cholesky_solve` (function)
- [ ] `torch.choose_qparams_optimized` (function)
- [x] `torch.chunk` (function)
- [ ] `torch.clamp` (function)
- [ ] `torch.clamp_` (function)
- [ ] `torch.clamp_max` (function)
- [ ] `torch.clamp_max_` (function)
- [ ] `torch.clamp_min` (function)
- [ ] `torch.clamp_min_` (function)
- [ ] `torch.clip` (function)
- [ ] `torch.clip_` (function)
- [ ] `torch.clone` (function)
- [ ] `torch.combinations` (function)
- [ ] `torch.complex` (function)
- [ ] `torch.conj` (function)
- [ ] `torch.constant_pad_nd` (function)
- [x] `torch.conv1d` (function)
- [x] `torch.conv2d` (function)
- [ ] `torch.conv3d` (function)
- [ ] `torch.conv_tbc` (function)
- [x] `torch.conv_transpose1d` (function)
- [ ] `torch.conv_transpose2d` (function)
- [ ] `torch.conv_transpose3d` (function)
- [ ] `torch.convolution` (function)
- [ ] `torch.cos` (function)
- [ ] `torch.cos_` (function)
- [ ] `torch.cosh` (function)
- [ ] `torch.cosh_` (function)
- [ ] `torch.cosine_embedding_loss` (function)
- [ ] `torch.cosine_similarity` (function)
- [ ] `torch.count_nonzero` (function)
- [ ] `torch.cross` (function)
- [ ] `torch.ctc_loss` (function)
- [ ] `torch.cudnn_affine_grid_generator` (function)
- [ ] `torch.cudnn_batch_norm` (function)
- [ ] `torch.cudnn_convolution` (function)
- [ ] `torch.cudnn_convolution_transpose` (function)
- [ ] `torch.cudnn_grid_sampler` (function)
- [ ] `torch.cudnn_is_acceptable` (function)
- [ ] `torch.cummax` (function)
- [ ] `torch.cummin` (function)
- [ ] `torch.cumprod` (function)
- [ ] `torch.cumsum` (function)
- [ ] `torch.deg2rad` (function)
- [ ] `torch.deg2rad_` (function)
- [ ] `torch.dequantize` (function)
- [ ] `torch.det` (function)
- [ ] `torch.detach` (function)
- [ ] `torch.detach_` (function)
- [ ] `torch.diag` (function)
- [ ] `torch.diag_embed` (function)
- [ ] `torch.diagflat` (function)
- [ ] `torch.diagonal` (function)
- [ ] `torch.digamma` (function)
- [ ] `torch.dist` (function)
- [ ] `torch.div` (function)
- [ ] `torch.divide` (function)
- [ ] `torch.dot` (function)
- [x] `torch.dropout` (function)
- [ ] `torch.dropout_` (function)
- [ ] `torch.dsmm` (function)
- [ ] `torch.dstack` (function)
- [ ] `torch.eig` (function)
- [ ] `torch.einsum` (function)
- [ ] `torch.embedding` (function)
- [ ] `torch.embedding_bag` (function)
- [ ] `torch.embedding_renorm_` (function)
- [ ] `torch.empty` (function)
- [ ] `torch.empty_like` (function)
- [ ] `torch.empty_meta` (function)
- [ ] `torch.empty_quantized` (function)
- [ ] `torch.empty_strided` (function)
- [ ] `torch.eq` (function)
- [ ] `torch.equal` (function)
- [ ] `torch.erf` (function)
- [ ] `torch.erf_` (function)
- [ ] `torch.erfc` (function)
- [ ] `torch.erfc_` (function)
- [ ] `torch.erfinv` (function)
- [ ] `torch.exp` (function)
- [ ] `torch.exp2` (function)
- [ ] `torch.exp2_` (function)
- [ ] `torch.exp_` (function)
- [ ] `torch.expm1` (function)
- [ ] `torch.expm1_` (function)
- [ ] `torch.eye` (function)
- [ ] `torch.fake_quantize_per_channel_affine` (function)
- [ ] `torch.fake_quantize_per_tensor_affine` (function)
- [ ] `torch.fbgemm_linear_fp16_weight` (function)
- [ ] `torch.fbgemm_linear_fp16_weight_fp32_activation` (function)
- [ ] `torch.fbgemm_linear_int8_weight` (function)
- [ ] `torch.fbgemm_linear_int8_weight_fp32_activation` (function)
- [ ] `torch.fbgemm_linear_quantize_weight` (function)
- [ ] `torch.fbgemm_pack_gemm_matrix_fp16` (function)
- [ ] `torch.fbgemm_pack_quantized_matrix` (function)
- [ ] `torch.feature_alpha_dropout` (function)
- [ ] `torch.feature_alpha_dropout_` (function)
- [ ] `torch.feature_dropout` (function)
- [ ] `torch.feature_dropout_` (function)
- [ ] `torch.fft` (function)
- [ ] `torch.fill_` (function)
- [ ] `torch.fix` (function)
- [ ] `torch.fix_` (function)
- [x] `torch.flatten` (function)
- [ ] `torch.flip` (function)
- [ ] `torch.fliplr` (function)
- [ ] `torch.flipud` (function)
- [ ] `torch.floor` (function)
- [ ] `torch.floor_` (function)
- [ ] `torch.floor_divide` (function)
- [ ] `torch.fmod` (function)
- [ ] `torch.frac` (function)
- [ ] `torch.frac_` (function)
- [ ] `torch.frobenius_norm` (function)
- [ ] `torch.from_file` (function)
- [x] `torch.from_numpy` (function)
- [ ] `torch.full` (function)
- [ ] `torch.full_like` (function)
- [ ] `torch.gather` (function)
- [ ] `torch.gcd` (function)
- [ ] `torch.gcd_` (function)
- [ ] `torch.ge` (function)
- [ ] `torch.geqrf` (function)
- [ ] `torch.ger` (function)
- [ ] `torch.get_device` (function)
- [ ] `torch.greater` (function)
- [x] `torch.greater_equal` (function)
- [ ] `torch.grid_sampler` (function)
- [ ] `torch.grid_sampler_2d` (function)
- [ ] `torch.grid_sampler_3d` (function)
- [x] `torch.group_norm` (function)
- [ ] `torch.gru` (function)
- [ ] `torch.gru_cell` (function)
- [ ] `torch.gt` (function)
- [ ] `torch.hamming_window` (function)
- [ ] `torch.hann_window` (function)
- [ ] `torch.hardshrink` (function)
- [ ] `torch.heaviside` (function)
- [ ] `torch.hinge_embedding_loss` (function)
- [ ] `torch.histc` (function)
- [ ] `torch.hsmm` (function)
- [ ] `torch.hspmm` (function)
- [ ] `torch.hstack` (function)
- [ ] `torch.hypot` (function)
- [ ] `torch.i0` (function)
- [ ] `torch.i0_` (function)
- [ ] `torch.ifft` (function)
- [ ] `torch.imag` (function)
- [ ] `torch.index_add` (function)
- [ ] `torch.index_copy` (function)
- [ ] `torch.index_fill` (function)
- [ ] `torch.index_put` (function)
- [ ] `torch.index_put_` (function)
- [ ] `torch.index_select` (function)
- [ ] `torch.instance_norm` (function)
- [ ] `torch.int_repr` (function)
- [ ] `torch.inverse` (function)
- [ ] `torch.irfft` (function)
- [ ] `torch.is_complex` (function)
- [ ] `torch.is_distributed` (function)
- [ ] `torch.is_floating_point` (function)
- [ ] `torch.is_nonzero` (function)
- [ ] `torch.is_same_size` (function)
- [ ] `torch.is_signed` (function)
- [ ] `torch.is_vulkan_available` (function)
- [ ] `torch.isclose` (function)
- [ ] `torch.isfinite` (function)
- [ ] `torch.isinf` (function)
- [ ] `torch.isnan` (function)
- [ ] `torch.isneginf` (function)
- [ ] `torch.isposinf` (function)
- [ ] `torch.isreal` (function)
- [ ] `torch.istft` (function)
- [ ] `torch.kaiser_window` (function)
- [ ] `torch.kl_div` (function)
- [ ] `torch.kthvalue` (function)
- [ ] `torch.layer_norm` (function)
- [ ] `torch.lcm` (function)
- [ ] `torch.lcm_` (function)
- [ ] `torch.le` (function)
- [ ] `torch.lerp` (function)
- [ ] `torch.less` (function)
- [ ] `torch.less_equal` (function)
- [ ] `torch.lgamma` (function)
- [ ] `torch.linspace` (function)
- [x] `torch.log` (function)
- [ ] `torch.log10` (function)
- [ ] `torch.log10_` (function)
- [ ] `torch.log1p` (function)
- [ ] `torch.log1p_` (function)
- [ ] `torch.log2` (function)
- [ ] `torch.log2_` (function)
- [ ] `torch.log_` (function)
- [x] `torch.log_softmax` (function)
- [ ] `torch.logaddexp` (function)
- [ ] `torch.logaddexp2` (function)
- [ ] `torch.logcumsumexp` (function)
- [ ] `torch.logdet` (function)
- [ ] `torch.logical_and` (function)
- [ ] `torch.logical_not` (function)
- [ ] `torch.logical_or` (function)
- [ ] `torch.logical_xor` (function)
- [ ] `torch.logit` (function)
- [ ] `torch.logit_` (function)
- [ ] `torch.logspace` (function)
- [ ] `torch.logsumexp` (function)
- [ ] `torch.lstm` (function)
- [ ] `torch.lstm_cell` (function)
- [ ] `torch.lstsq` (function)
- [ ] `torch.lt` (function)
- [ ] `torch.lu_solve` (function)
- [ ] `torch.margin_ranking_loss` (function)
- [ ] `torch.masked_fill` (function)
- [ ] `torch.masked_scatter` (function)
- [ ] `torch.masked_select` (function)
- [ ] `torch.matmul` (function)
- [ ] `torch.matrix_exp` (function)
- [ ] `torch.matrix_power` (function)
- [ ] `torch.matrix_rank` (function)
- [x] `torch.max` (function)
- [ ] `torch.max_pool1d` (function)
- [ ] `torch.max_pool1d_with_indices` (function)
- [x] `torch.max_pool2d` (function)
- [ ] `torch.max_pool3d` (function)
- [ ] `torch.maximum` (function)
- [ ] `torch.mean` (function)
- [ ] `torch.median` (function)
- [ ] `torch.meshgrid` (function)
- [ ] `torch.min` (function)
- [ ] `torch.minimum` (function)
- [ ] `torch.miopen_batch_norm` (function)
- [ ] `torch.miopen_convolution` (function)
- [ ] `torch.miopen_convolution_transpose` (function)
- [ ] `torch.miopen_depthwise_convolution` (function)
- [ ] `torch.miopen_rnn` (function)
- [ ] `torch.mkldnn_adaptive_avg_pool2d` (function)
- [ ] `torch.mkldnn_convolution` (function)
- [ ] `torch.mkldnn_convolution_backward_weights` (function)
- [ ] `torch.mkldnn_max_pool2d` (function)
- [ ] `torch.mkldnn_max_pool3d` (function)
- [ ] `torch.mm` (function)
- [ ] `torch.mode` (function)
- [x] `torch.movedim` (function)
- [x] `torch.mul` (function)
- [ ] `torch.multinomial` (function)
- [ ] `torch.multiply` (function)
- [ ] `torch.mv` (function)
- [ ] `torch.mvlgamma` (function)
- [ ] `torch.nanquantile` (function)
- [ ] `torch.nansum` (function)
- [ ] `torch.narrow` (function)
- [ ] `torch.native_batch_norm` (function)
- [ ] `torch.native_group_norm` (function)
- [ ] `torch.native_layer_norm` (function)
- [ ] `torch.native_norm` (function)
- [ ] `torch.ne` (function)
- [ ] `torch.neg` (function)
- [ ] `torch.neg_` (function)
- [ ] `torch.negative` (function)
- [ ] `torch.negative_` (function)
- [ ] `torch.nextafter` (function)
- [ ] `torch.nonzero` (function)
- [x] `torch.norm` (function)
- [x] `torch.norm_except_dim` (function)
- [ ] `torch.normal` (function)
- [ ] `torch.not_equal` (function)
- [ ] `torch.nuclear_norm` (function)
- [ ] `torch.numel` (function)
- [x] `torch.ones` (function)
- [ ] `torch.ones_like` (function)
- [ ] `torch.orgqr` (function)
- [ ] `torch.ormqr` (function)
- [ ] `torch.outer` (function)
- [ ] `torch.pairwise_distance` (function)
- [ ] `torch.pdist` (function)
- [ ] `torch.pinverse` (function)
- [ ] `torch.pixel_shuffle` (function)
- [ ] `torch.poisson` (function)
- [ ] `torch.poisson_nll_loss` (function)
- [ ] `torch.polar` (function)
- [ ] `torch.polygamma` (function)
- [x] `torch.pow` (function)
- [ ] `torch.prelu` (function)
- [ ] `torch.prod` (function)
- [x] `torch.promote_types` (function)
- [ ] `torch.q_per_channel_axis` (function)
- [ ] `torch.q_per_channel_scales` (function)
- [ ] `torch.q_per_channel_zero_points` (function)
- [ ] `torch.q_scale` (function)
- [ ] `torch.q_zero_point` (function)
- [ ] `torch.qr` (function)
- [ ] `torch.quantile` (function)
- [ ] `torch.quantize_per_channel` (function)
- [ ] `torch.quantize_per_tensor` (function)
- [ ] `torch.quantized_batch_norm` (function)
- [ ] `torch.quantized_gru_cell` (function)
- [ ] `torch.quantized_lstm_cell` (function)
- [ ] `torch.quantized_max_pool1d` (function)
- [ ] `torch.quantized_max_pool2d` (function)
- [ ] `torch.quantized_rnn_relu_cell` (function)
- [ ] `torch.quantized_rnn_tanh_cell` (function)
- [ ] `torch.rad2deg` (function)
- [ ] `torch.rad2deg_` (function)
- [ ] `torch.rand` (function)
- [ ] `torch.rand_like` (function)
- [ ] `torch.randint` (function)
- [ ] `torch.randint_like` (function)
- [ ] `torch.randn` (function)
- [ ] `torch.randn_like` (function)
- [ ] `torch.randperm` (function)
- [ ] `torch.range` (function)
- [ ] `torch.real` (function)
- [ ] `torch.reciprocal` (function)
- [ ] `torch.reciprocal_` (function)
- [x] `torch.relu` (function)
- [ ] `torch.relu_` (function)
- [ ] `torch.remainder` (function)
- [ ] `torch.renorm` (function)
- [ ] `torch.repeat_interleave` (function)
- [x] `torch.reshape` (function)
- [ ] `torch.resize_as_` (function)
- [x] `torch.result_type` (function)
- [ ] `torch.rfft` (function)
- [ ] `torch.rnn_relu` (function)
- [ ] `torch.rnn_relu_cell` (function)
- [ ] `torch.rnn_tanh` (function)
- [ ] `torch.rnn_tanh_cell` (function)
- [ ] `torch.roll` (function)
- [ ] `torch.rot90` (function)
- [ ] `torch.round` (function)
- [ ] `torch.round_` (function)
- [ ] `torch.rrelu` (function)
- [ ] `torch.rrelu_` (function)
- [ ] `torch.rsqrt` (function)
- [ ] `torch.rsqrt_` (function)
- [ ] `torch.rsub` (function)
- [ ] `torch.saddmm` (function)
- [ ] `torch.scalar_tensor` (function)
- [ ] `torch.scatter` (function)
- [ ] `torch.scatter_add` (function)
- [ ] `torch.searchsorted` (function)
- [ ] `torch.select` (function)
- [ ] `torch.selu` (function)
- [ ] `torch.selu_` (function)
- [ ] `torch.sgn` (function)
- [x] `torch.sigmoid` (function)
- [ ] `torch.sigmoid_` (function)
- [ ] `torch.sign` (function)
- [ ] `torch.signbit` (function)
- [ ] `torch.sin` (function)
- [ ] `torch.sin_` (function)
- [ ] `torch.sinh` (function)
- [ ] `torch.sinh_` (function)
- [ ] `torch.slogdet` (function)
- [ ] `torch.smm` (function)
- [x] `torch.softmax` (function)
- [ ] `torch.solve` (function)
- [ ] `torch.sort` (function)
- [ ] `torch.sparse_coo_tensor` (function)
- [ ] `torch.split` (function)
- [ ] `torch.split_with_sizes` (function)
- [ ] `torch.spmm` (function)
- [ ] `torch.sqrt` (function)
- [ ] `torch.sqrt_` (function)
- [ ] `torch.square` (function)
- [ ] `torch.square_` (function)
- [ ] `torch.squeeze` (function)
- [ ] `torch.sspaddmm` (function)
- [ ] `torch.stack` (function)
- [ ] `torch.std` (function)
- [ ] `torch.std_mean` (function)
- [ ] `torch.stft` (function)
- [x] `torch.sub` (function)
- [ ] `torch.subtract` (function)
- [ ] `torch.sum` (function)
- [ ] `torch.svd` (function)
- [ ] `torch.symeig` (function)
- [ ] `torch.t` (function)
- [ ] `torch.take` (function)
- [ ] `torch.tan` (function)
- [ ] `torch.tan_` (function)
- [x] `torch.tanh` (function)
- [ ] `torch.tanh_` (function)
- [ ] `torch.tensordot` (function)
- [ ] `torch.threshold` (function)
- [ ] `torch.threshold_` (function)
- [ ] `torch.topk` (function)
- [ ] `torch.trace` (function)
- [x] `torch.transpose` (function)
- [ ] `torch.trapz` (function)
- [ ] `torch.triangular_solve` (function)
- [ ] `torch.tril` (function)
- [ ] `torch.tril_indices` (function)
- [ ] `torch.triplet_margin_loss` (function)
- [ ] `torch.triu` (function)
- [ ] `torch.triu_indices` (function)
- [ ] `torch.true_divide` (function)
- [ ] `torch.trunc` (function)
- [ ] `torch.trunc_` (function)
- [ ] `torch.unbind` (function)
- [ ] `torch.unique_consecutive` (function)
- [ ] `torch.unsafe_chunk` (function)
- [ ] `torch.unsafe_split` (function)
- [ ] `torch.unsafe_split_with_sizes` (function)
- [ ] `torch.unsqueeze` (function)
- [ ] `torch.vander` (function)
- [ ] `torch.var` (function)
- [ ] `torch.var_mean` (function)
- [ ] `torch.vdot` (function)
- [ ] `torch.view_as_complex` (function)
- [ ] `torch.view_as_real` (function)
- [ ] `torch.vstack` (function)
- [ ] `torch.where` (function)
- [ ] `torch.zero_` (function)
- [x] `torch.zeros` (function)
- [ ] `torch.zeros_like` (function)
- [ ] `torch.distributed` (module)
- [ ] `torch.testing` (module)
- [ ] `torch.overrides` (module)
- [ ] `torch.futures` (module)
- [x] `torch.autograd` (module)
- [x] `torch.nn` (module)
- [ ] `torch.functional` (module)
- [ ] `torch.lu` (function)
- [ ] `torch.lu_unpack` (function)
- [ ] `torch.pca_lowrank` (function)
- [ ] `torch.svd_lowrank` (function)
- [ ] `torch.unique` (function)
- [x] `torch.no_grad` (class)
- [ ] `torch.enable_grad` (class)
- [ ] `torch.set_grad_enabled` (class)
- [ ] `torch.backends` (module)
- [x] `torch.jit` (module)
- [ ] `torch.optim` (module)
- [ ] `torch.multiprocessing` (module)
- [x] `torch.onnx` (module)
- [ ] `torch.linalg` (module)
- [ ] `torch.hub` (module)
- [ ] `torch.distributions` (module)
- [ ] `torch.quantization` (module)
- [ ] `torch.compiled_with_cxx11_abi` (function)
- [ ] `torch.ops` (_Ops)
- [ ] `torch.classes` (_Classes)
- [ ] `torch.quasirandom` (module)
- [ ] `torch.legacy_contiguous_format` (memory_format)
- [ ] `torch.lobpcg` (function)
- [ ] `torch.quantized_lstm` (function)
- [ ] `torch.quantized_gru` (function)
- [ ] `torch.Assert` (function)
